@@ -13,11 +13,11 @@ from io import BytesIO
 
 from aiohttp import FormData
 from http_tools import AbmServiceConnector
-from http_tools.attached_file import AttachedFile
 from http_tools.mime_types import ContentType
 from init_helpers import custom_dumps
 from init_helpers.dict_to_dataclass import dict_to_dataclass, FieldErrors
 
+
 logger = logging.getLogger(__name__)
 
 
@@ -56,12 +56,18 @@ class Email:
     attached_files: list[EmailAttachedFile]
 
 
-@dataclass
+@dataclass(slots=True)
 class SendSettings:
     sender_name: str
     send_priority: SendPriority
 
 
+@dataclass(slots=True)
+class AttachedFile:
+    content: bytes
+    filename: str
+
+
 class EmailServiceV2Connector:
     @dataclass(kw_only=True)
     class Config(AbmServiceConnector.Config):
@@ -69,7 +75,7 @@ class EmailServiceV2Connector:
         send_priority: SendPriority = SendPriority.medium
 
     @dataclass
-    class Context(AbmServiceConnector):
+    class Context(AbmServiceConnector.Context):
         project_name: str
 
     def __init__(self, config: Config, context: Context) -> None:
